<?php

namespace Lavalite\Kefu\Http\Controllers\Api;

use App\Http\Controllers\Api\UserController as BaseController;
use Lavalite\Kefu\Http\Requests\CustomerservicesettingRequest;
use Lavalite\Kefu\Interfaces\CustomerservicesettingRepositoryInterface;
use Lavalite\Kefu\Models\Customerservicesetting;

/**
 * User API controller class.
 */
class CustomerservicesettingUserController extends BaseController
{
    /**
     * Initialize customerservicesetting controller.
     *
     * @param type CustomerservicesettingRepositoryInterface $customerservicesetting
     *
     * @return type
     */
    public function __construct(CustomerservicesettingRepositoryInterface $customerservicesetting)
    {
        $this->repository = $customerservicesetting;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Lavalite\Kefu\Repositories\Criteria\CustomerservicesettingUserCriteria());
        parent::__construct();
    }

    /**
     * Display a list of customerservicesetting.
     *
     * @return json
     */
    public function index(CustomerservicesettingRequest $request)
    {
        $customerservicesettings  = $this->repository
            ->setPresenter('\\Lavalite\\Kefu\\Repositories\\Presenter\\CustomerservicesettingListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $customerservicesettings['code'] = 2000;
        return response()->json($customerservicesettings) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display customerservicesetting.
     *
     * @param Request $request
     * @param Model   Customerservicesetting
     *
     * @return Json
     */
    public function show(CustomerservicesettingRequest $request, Customerservicesetting $customerservicesetting)
    {

        if ($customerservicesetting->exists) {
            $customerservicesetting         = $customerservicesetting->presenter();
            $customerservicesetting['code'] = 2001;
            return response()->json($customerservicesetting)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new customerservicesetting.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(CustomerservicesettingRequest $request, Customerservicesetting $customerservicesetting)
    {
        $customerservicesetting         = $customerservicesetting->presenter();
        $customerservicesetting['code'] = 2002;
        return response()->json($customerservicesetting)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new customerservicesetting.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(CustomerservicesettingRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $customerservicesetting          = $this->repository->create($attributes);
            $customerservicesetting          = $customerservicesetting->presenter();
            $customerservicesetting['code']  = 2004;

            return response()->json($customerservicesetting)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show customerservicesetting for editing.
     *
     * @param Request $request
     * @param Model   $customerservicesetting
     *
     * @return json
     */
    public function edit(CustomerservicesettingRequest $request, Customerservicesetting $customerservicesetting)
    {
        if ($customerservicesetting->exists) {
            $customerservicesetting         = $customerservicesetting->presenter();
            $customerservicesetting['code'] = 2003;
            return response()-> json($customerservicesetting)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the customerservicesetting.
     *
     * @param Request $request
     * @param Model   $customerservicesetting
     *
     * @return json
     */
    public function update(CustomerservicesettingRequest $request, Customerservicesetting $customerservicesetting)
    {
        try {

            $attributes = $request->all();

            $customerservicesetting->update($attributes);
            $customerservicesetting         = $customerservicesetting->presenter();
            $customerservicesetting['code'] = 2005;

            return response()->json($customerservicesetting)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the customerservicesetting.
     *
     * @param Request $request
     * @param Model   $customerservicesetting
     *
     * @return json
     */
    public function destroy(CustomerservicesettingRequest $request, Customerservicesetting $customerservicesetting)
    {

        try {

            $t = $customerservicesetting->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('kefu::customerservicesetting.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
