<?php

namespace Lavalite\Kefu\Http\Controllers;
use Litepie\Kefu\Http\Requests\CustomerservicesettingRequest;
use Litepie\Kefu\Models\Customerservicesetting;

trait CustomerservicesettingWorkflow {
	
    /**
     * Workflow controller function for customerservicesetting.
     *
     * @param Model   $customerservicesetting
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CustomerservicesettingRequest $request, Customerservicesetting $customerservicesetting, $step)
    {

        try {

            $customerservicesetting->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('kefu::customerservicesetting.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/customerservicesetting/customerservicesetting/' . $customerservicesetting->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/customerservicesetting/customerservicesetting/' . $customerservicesetting->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for customerservicesetting.
     *
     * @param Model   $customerservicesetting
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Customerservicesetting $customerservicesetting, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $customerservicesetting->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('kefu::customerservicesetting.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('kefu::admin.customerservicesetting.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('kefu::admin.customerservicesetting.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('kefu::admin.customerservicesetting.message', $data)->render();

        }

    }
}