<?php

namespace Lavalite\Kefu\Policies;

use App\User;
use Lavalite\Kefu\Models\Customerservicesetting;

class CustomerservicesettingPolicy
{

    /**
     * Determine if the given user can view the customerservicesetting.
     *
     * @param User $user
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool
     */
    public function view(User $user, Customerservicesetting $customerservicesetting)
    {
        if ($user->canDo('kefu.customerservicesetting.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $customerservicesetting->user_id;
    }

    /**
     * Determine if the given user can create a customerservicesetting.
     *
     * @param User $user
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('kefu.customerservicesetting.create');
    }

    /**
     * Determine if the given user can update the given customerservicesetting.
     *
     * @param User $user
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool
     */
    public function update(User $user, Customerservicesetting $customerservicesetting)
    {
        if ($user->canDo('kefu.customerservicesetting.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $customerservicesetting->user_id;
    }

    /**
     * Determine if the given user can delete the given customerservicesetting.
     *
     * @param User $user
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool
     */
    public function destroy(User $user, Customerservicesetting $customerservicesetting)
    {
        if ($user->canDo('kefu.customerservicesetting.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $customerservicesetting->user_id;
    }

    /**
     * Determine if the given user can verify the given customerservicesetting.
     *
     * @param User $user
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool
     */
    public function verify(User $user, Customerservicesetting $customerservicesetting)
    {
        if ($user->canDo('kefu.customerservicesetting.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('kefu.customerservicesetting.verify') 
        && $user->is('manager')
        && $customerservicesetting->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given customerservicesetting.
     *
     * @param User $user
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool
     */
    public function approve(User $user, Customerservicesetting $customerservicesetting)
    {
        if ($user->canDo('kefu.customerservicesetting.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
