<?php

namespace Lavalite\Kefu\Providers;

use Illuminate\Support\ServiceProvider;

class KefuServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'kefu');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'kefu');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('kefu', function ($app) {
            return $this->app->make('Lavalite\Kefu\Kefu');
        });

        // Bind Customerservicesetting to repository
        $this->app->bind(
            \Lavalite\Kefu\Interfaces\CustomerservicesettingRepositoryInterface::class,
            \Lavalite\Kefu\Repositories\Eloquent\CustomerservicesettingRepository::class
        );

        $this->app->register(\Lavalite\Kefu\Providers\AuthServiceProvider::class);
        $this->app->register(\Lavalite\Kefu\Providers\EventServiceProvider::class);
        $this->app->register(\Lavalite\Kefu\Providers\RouteServiceProvider::class);
        // $this->app->register(\Lavalite\Kefu\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['kefu'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('lavalite/kefu.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/kefu')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/kefu')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
