<?php

namespace Lavalite\Kefu\Workflow;

use Lavalite\Kefu\Models\Customerservicesetting;
use Validator;

class CustomerservicesettingValidator
{

    /**
     * Determine if the given customerservicesetting is valid for complete status.
     *
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool / Validator
     */
    public function complete(Customerservicesetting $customerservicesetting)
    {
        return Validator::make($customerservicesetting->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given customerservicesetting is valid for verify status.
     *
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool / Validator
     */
    public function verify(Customerservicesetting $customerservicesetting)
    {
        return Validator::make($customerservicesetting->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given customerservicesetting is valid for approve status.
     *
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool / Validator
     */
    public function approve(Customerservicesetting $customerservicesetting)
    {
        return Validator::make($customerservicesetting->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given customerservicesetting is valid for publish status.
     *
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool / Validator
     */
    public function publish(Customerservicesetting $customerservicesetting)
    {
        return Validator::make($customerservicesetting->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given customerservicesetting is valid for archive status.
     *
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool / Validator
     */
    public function archive(Customerservicesetting $customerservicesetting)
    {
        return Validator::make($customerservicesetting->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given customerservicesetting is valid for unpublish status.
     *
     * @param Customerservicesetting $customerservicesetting
     *
     * @return bool / Validator
     */
    public function unpublish(Customerservicesetting $customerservicesetting)
    {
        return Validator::make($customerservicesetting->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
